$set matout "'matsol.gdx', prd, cost, ghg, inst ";

SET
tech                     technology options                              /bioch4,beetetoh,starchetoh,rme,sng,lignoetoh,ft,ker,lbm,lsng/
market                   fuel markets                                    /land,aviation,goodsland,ship/
techLand(tech)           technology options land                         /bioch4,beetetoh,starchetoh,rme,sng,lignoetoh,ft/
*techWood(tech)           technology options wood based                   /sng,btl/
techAvi(tech)            technology options aviation                     /ker/
techGoodsLand(tech)      technology options goods land                   /bioch4,rme,sng,ft,lbm,lsng/
*techGoodsLand(tech)      technology options goods land                   /bioch4,beetetoh,starchetoh,rme,sng,lignoetoh,ft,lbm,lsng/
techShip(tech)           technology options ship                         /rme,ft,lbm,lsng/
techDiesel(tech)         fuel options diesel                             /rme,ft/
techPetrol(tech)         fuel options petrol                             /beetetoh,starchetoh,lignoetoh/
techGas(tech)            fuel options gas                                /bioch4,sng/
*biomassRes              biomass residue availability
time                     global time                                     /2017*2050/
t(time)                  model time points                               /2017*2050/
;

SCALARS
rampF                    capacity expansion ramp per year                /0.5/
*rampP                    production expansion ramp per year              /4/
rampC                    constant capacity expansion ramp per year       /25/
rampMin                  minimum capacity expansion ramp per year       /0.1/
lifeT                    capacity lifetime                               /25/
*biomassLim               biomass limit                                   /500/
infraGHG                 Infrastructure GHG emissions [ktCO2 per PJcap]  /3/
*totalCostLimit           Total cost limit []                            /10e15/
gasLim                   gas limit
fuelQuota                fuel mix diesel div by petrol
;

PARAMETERS
*demLand(time)            demand land GJ
*demAviation(time)        demand aviation GJ
aviationMinQuota(time)   aviation minimum quota
landMax(time)            arable land limit
demand(time,market)      demand matrix [PJ]
costInv(time,tech)       investment cost (Euro per GJ)
costMarg(time,tech)      marginal cost
cap0(time,tech)          initial capacity (continuously decommissioned)
ghgAbate(time,tech)      GHG-Abatement (kgCO2 per GJ fuel or ktCO2 per PJ)
landDmdGJ(time,tech)     Land demand (ha per GJ fuel)
;

$gdxin matdata.gdx
$loadR costMarg, costInv, demand, cap0, ghgAbate, landDmdGJ, gasLim, fuelQuota, landMax, aviationMinQuota

FREE VARIABLES
cost                     Total system cost
ghg                      Total system ghg-abatement;

POSITIVE VARIABLES
inst(time,tech)          new installed capacity (PJ)
deco(time,tech)          capacity decommission (PJ)
cap(time,tech)           capacity (PJ)
capCumul(time,tech)      cumulative capacity (PJ)
prd(time,tech,market)    production      (PJ)
land(time,tech)          arable land used (ha);

cap.fx('2017',tech)      = cap0('2017',tech);
capCumul.fx('2017',tech) = cap0('2017',tech);
inst.fx('2017',tech)     = 0;
inst.up(time,tech)       = rampC;
cap.fx(time,tech)$(gasLim<0.1 and techGas(tech))       = gasLim;

*prd.up(time,'btl')       = sum(market,demand(time,market));
prd.up(time,tech,'aviation')$(not techAvi(tech))           = 0;
prd.up(time,tech,'goodsland')$(not techGoodsLand(tech))    = 0;
prd.up(time,tech,'ship')$(not techShip(tech))              = 0;


EQUATION
capexp           capacity expansion
capdeco          capacity decommission
prdLim           production limit
instRamp         installation ramp limit
*prodRamp         production ramp limit
*demLim1          total demand limitation1
*demLim2           total demand limitation2
demLimLand       demand satisfaction land
demLimAviation   demand satisfaction aviation
demLimMinAviation   demand satisfaction aviation
demLimGoodsLand  demand satisfaction goods land
demLimShip       demand satisfaction ship
totGhg           GHG-abatement
totCost          total cost
*totCostLim       total cost limit
landUse          land use
quota            fuel mix quota
;

capexp(t+1,tech)..          cap(t+1,tech)                        =E=   cap(t,tech)+inst(t+1,tech)-cap0(t,tech)+cap0(t+1,tech)-deco(t+1,tech);
capdeco(t+lifeT,tech)..     deco(t+lifeT,tech)                   =E=   inst(t,tech);
prdlim(t,tech)..            cap(t,tech)                          =G=   sum(market,prd(t,tech,market));
*instRamp(t+1,tech)..        inst(t+1,tech)                       =L=  rampMin+(rampF-1)*cap(t,tech);
instRamp(t+1,tech)..        inst(t+1,tech)                       =L=   rampMin+rampF*cap(t,tech);
*prodRamp(t+1,tech)..        sum(market,prd(t+1,tech,market))     =L=   rampF*sum(market,prd(t,tech,market));
*demLim1(t)..                sum((tech,market),prd(t,tech,market))=L=   sum(market,demand(t,market));
*demLim2(t)..                demLand(t)+demAviation(t)           =G=   prd(t,'btl')+sum(tech$(tech<>'btl'),prd(t,tech));

*demLim(t)..                 sum(market,demand(t,market))        =G=   sum(tech,prd(t,tech));
demLimLand(t)..             demand(t,'land')                     =G=   sum(tech,prd(t,tech,'land'));
demLimAviation(t)..         demand(t,'aviation')                 =G=   sum(tech,prd(t,tech,'aviation'));
demLimMinAviation(t)..      demand(t,'aviation')*aviationMinQuota(t)=L=   sum(tech,prd(t,tech,'aviation'));
demLimGoodsLand(t)..        demand(t,'goodsland')                =G=   sum(tech,prd(t,tech,'goodsland'));
demLimShip(t)..             demand(t,'ship')                     =G=   sum(tech,prd(t,tech,'ship'));
landUse(t)..                landMax(t)                           =G=   sum((tech,market),landDmdGJ(t,tech)*prd(t,tech,market));

quota(t)$(fuelQuota=0.5)..  fuelQuota*sum(techPetrol,prd(t,techPetrol,'land'))  =E=   sum(techDiesel,prd(t,techDiesel,'land'));
*totCostLim..                cost                                 =L=   totalCostLimit;

totCost..                   cost                                 =E=   sum((t,tech,market),costMarg(t,tech)*prd(t,tech,market))
                                                                                 + sum((t,tech),costInv(t,tech)*inst(t,tech));
totGhg..                    ghg                                  =E=   sum((t,tech,market),ghgAbate(t,tech)*prd(t,tech,market))
                                                                                 - sum((t,tech),infraGHG*inst(t,tech));

MODEL benopt /all/

SOLVE benopt using lp maximizing ghg;

Display prd.l,inst.l,deco.l,cap.l,ghg.l,cost.l;

execute_unload %matout%;
