function [] = plotBarStackGroups(stackDataPos, stackDataNeg, TC, TCmax, MC, groupLabels)
%% Plot a set of stacked bars, but group them according to labels provided.
%%
%% Params: 
%%      stackData is a 3D matrix (i.e., stackData(i, j, k) => (Group, Stack, StackElement)) 
%%      groupLabels is a CELL type (i.e., { 'a', 1 , 20, 'because' };)
%%
%% Copyright 2011 Evan Bollig (bollig at scs DOT fsu ANOTHERDOT edu
%%
%% 
NumGroupsPerAxis = size(stackDataPos, 1);
NumStacksPerGroup = size(stackDataPos, 2);
NumVariablesPerStackPos = size(stackDataPos, 3);
NumVariablesPerStackNeg = size(stackDataNeg, 3);


% Count off the number of bins
groupBins = 1:NumGroupsPerAxis;
MaxGroupWidth = 0.8; % Fraction of 1. If 1, then we have all bars in groups touching
groupOffset = MaxGroupWidth/NumStacksPerGroup;

% chsv=colormap(hsv(NumVariablesPerStackPos+NumVariablesPerStackNeg));
chsv=[59,157,166;210,226,136;204,231,211;151,191,12;220,158,0;128,103,0;180,11,67;100,100,100;200,200,200;0,0,0;0,0,0;0,0,0;0,0,0]/255;



for i=1:NumStacksPerGroup

    Y1 = squeeze(stackDataPos(:,i,:));
    Y2 = squeeze(stackDataNeg(:,i,:));
    
    % Center the bars:    
    internalPosCount = i - ((NumStacksPerGroup+1) / 2);
    
    % Offset the group draw positions:
    groupDrawPos = (internalPosCount)* groupOffset + groupBins;
    
    h1(i,:) = bar(Y1, 'stacked');
    h2(i,:) = bar(Y2, 'stacked');
    hTC(i,:) = bar(TC(i,:));
    hTCmax(i,:) = stem(TCmax(i,:),'filled');
    hMC(i,:) = bar(MC(i,:));
    
    for j=1:NumVariablesPerStackPos
        set(h1(i,j),'FaceColor',chsv(j,:))
        set(h1(i,j),'EdgeColor','none');%[0 0 0],'LineWidth',0)
    end
    for j=1:NumVariablesPerStackNeg
        set(h2(i,j),'FaceColor',chsv(j+NumVariablesPerStackPos,:))
        set(h2(i,j),'EdgeColor','none');%[0 0 0],'LineWidth',0)
    end
    set(hTC(i,:),'FaceColor',[0 0 0])
    set(hTCmax(i,:),'Color',[0 0 0])
    set(hMC(i,:),'FaceColor',[1 1 1])
    set(h1(i,:),'BarWidth',groupOffset);
    set(h1(i,:),'XData',groupDrawPos);
    set(h2(i,:),'BarWidth',groupOffset);
    set(h2(i,:),'XData',groupDrawPos);
    set(hTC(i,:),'BarWidth',groupOffset/2);
    set(hTC(i,:),'XData',groupDrawPos);
%     set(hTCmax(i,:),'BarWidth',groupOffset/30);
    set(hTCmax(i,:),'XData',groupDrawPos);
    set(hMC(i,:),'BarWidth',groupOffset/3);
    set(hMC(i,:),'XData',groupDrawPos);
end
hold off;

set(gca,'XTickMode','manual');
set(gca,'XTick',1:NumGroupsPerAxis);
set(gca,'XTickLabelMode','manual');
set(gca,'XTickLabel',groupLabels);
% set(gca,'LineStyle','-','LineWidth',0.5,'EdgeColor','black')
end 